@@ -24,6 +24,11 @@
 #include "messagecomposer_export.h"
 #include "plugineditorcheckbeforesendparams.h"
 
+namespace KIdentityManagement
+{
+class IdentityManager;
+}
+
 namespace MessageComposer
 {
 class PluginEditorCheckBeforeSendInterfacePrivate;
@@ -41,6 +46,10 @@ public:
     void setParentWidget(QWidget *parent);
     QWidget *parentWidget() const;
 
+    void setIdentityManagement(KIdentityManagement::IdentityManager *identityManagement);
+    KIdentityManagement::IdentityManager *identityManagement() const;
+
+
     void setParameters(const MessageComposer::PluginEditorCheckBeforeSendParams &params);
     MessageComposer::PluginEditorCheckBeforeSendParams parameters() const;
 
