@@ -65,17 +65,6 @@ using namespace MessageViewer;
 Q_DECLARE_METATYPE(GpgME::DecryptionResult::Recipient)
 Q_DECLARE_METATYPE(const Kleo::CryptoBackend::Protocol *)
 
-static QString iconToDataUrl(const QString &iconPath)
-{
-    QFile f(iconPath);
-    if (!f.open(QIODevice::ReadOnly)) {
-        return QString();
-    }
-
-    const QByteArray ba = f.readAll();
-    return QStringLiteral("data:image/png;base64,%1").arg(QLatin1String(ba.toBase64().constData()));
-}
-
 /** Check if the newline at position @p newLinePos in string @p s
     seems to separate two paragraphs (important for correct BiDi
     behavior, but is heuristic because paragraphs are not
@@ -700,14 +689,12 @@ public:
         int currQuoteLevel = -2; // -2 == no previous lines
         bool curHidden = false; // no hide any block
 
+
+        QString collapseIconPath;
+        QString mExpandIconPath;
         if (source()->showExpandQuotesMark()) {
-            // Cache Icons
-            if (mCollapseIcon.isEmpty()) {
-                mCollapseIcon = iconToDataUrl(IconNameCache::instance()->iconPath(QStringLiteral("quotecollapse"), 0));
-            }
-            if (mExpandIcon.isEmpty()) {
-                mExpandIcon = iconToDataUrl(IconNameCache::instance()->iconPath(QStringLiteral("quoteexpand"), 0));
-            }
+            collapseIconPath = IconNameCache::instance()->iconPathFromLocal(QStringLiteral("quotecollapse.png"));
+            mExpandIconPath = IconNameCache::instance()->iconPathFromLocal(QStringLiteral("quoteexpand.png"));
         }
 
         int previousQuoteDepth = -1;
@@ -751,7 +738,7 @@ public:
 
             // This quoted line needs be hidden
             if (source()->showExpandQuotesMark() && source()->levelQuote() >= 0
-                    && source()->levelQuote() <= (actQuoteLevel)) {
+                    && source()->levelQuote() <= actQuoteLevel) {
                 actHidden = true;
             }
 
@@ -764,7 +751,7 @@ public:
                 }
                 //Close blockquote
                 if (previousQuoteDepth > actQuoteLevel) {
-                    htmlStr += cssHelper()->addEndBlockQuote((previousQuoteDepth - actQuoteLevel));
+                    htmlStr += cssHelper()->addEndBlockQuote(previousQuoteDepth - actQuoteLevel);
                 }
 
                 /* start new quotelevel */
@@ -772,6 +759,10 @@ public:
                     htmlStr += normalStartTag;
                 } else {
                     if (source()->showExpandQuotesMark()) {
+                        // Add blockquote
+                        if (previousQuoteDepth < actQuoteLevel) {
+                            htmlStr += cssHelper()->addStartBlockQuote(actQuoteLevel - previousQuoteDepth);
+                        }
                         if (actHidden) {
                             //only show the QuoteMark when is the first line of the level hidden
                             if (!curHidden) {
@@ -780,16 +771,15 @@ public:
                                 htmlStr += QStringLiteral("<a href=\"kmail:levelquote?%1 \">"
                                                           "<img src=\"%2\"/></a>")
                                            .arg(-1)
-                                           .arg(mExpandIcon);
+                                           .arg(mExpandIconPath);
                                 htmlStr += QLatin1String("</div><br/>");
-                                htmlStr += quoteEnd;
                             }
                         } else {
                             htmlStr += QLatin1String("<div class=\"quotelevelmark\" >");
                             htmlStr += QStringLiteral("<a href=\"kmail:levelquote?%1 \">"
                                                       "<img src=\"%2\"/></a>")
                                        .arg(actQuoteLevel)
-                                       .arg(mCollapseIcon);
+                                       .arg(collapseIconPath);
                             htmlStr += QLatin1String("</div>");
                             if (actQuoteLevel < 3) {
                                 htmlStr += quoteFontTag[actQuoteLevel];
@@ -797,11 +787,6 @@ public:
                                 htmlStr += deepQuoteFontTag[actQuoteLevel % 3];
                             }
                         }
-                        // Add blockquote
-                        if (previousQuoteDepth < actQuoteLevel) {
-                            htmlStr += cssHelper()->addStartBlockQuote(actQuoteLevel - previousQuoteDepth);
-                        }
-
                     } else {
                         // Add blockquote
                         if (previousQuoteDepth < actQuoteLevel) {
@@ -830,10 +815,12 @@ public:
                     // if quoteLengh == 0 && foundQuote => a simple quote
                     if (foundQuote) {
                         quoteLength++;
-                        htmlStr += QStringLiteral("<span class=\"quotemarks\">%1</span>").arg(line.left(quoteLength));
                         const int rightString = (line.length()) - quoteLength;
                         if (rightString > 0) {
+                            htmlStr += QStringLiteral("<span class=\"quotemarks\">%1</span>").arg(line.left(quoteLength));
                             htmlStr += QStringLiteral("<font color=\"%1\">").arg(cssHelper()->quoteColorName(actQuoteLevel)) + KTextToHTML::convertToHtml(line.right(rightString), convertFlags) + QStringLiteral("</font>");
+                        } else {
+                            htmlStr += QStringLiteral("<span class=\"quotemarksemptyline\">%1</span>").arg(line.left(quoteLength));
                         }
                     } else {
                         htmlStr += KTextToHTML::convertToHtml(line, convertFlags);
@@ -1407,8 +1394,6 @@ private:
     HtmlWriter *mOldWriter;
 
     CSSHelperBase *mCSSHelper;
-    QString mCollapseIcon;
-    QString mExpandIcon;
 };
 
 DefaultRenderer::DefaultRenderer(const MimeTreeParser::Interface::MessagePart::Ptr &msgPart, CSSHelperBase *cssHelper)
