@@ -122,7 +122,8 @@ public:
         UseGlobalSetting = 0,
         Text = 1,
         Html = 2,
-        Unknown = 3
+        Unknown = 3,
+        ICal = 4
     };
 
     enum AttachmentAction {
@@ -234,7 +235,7 @@ public:
     void enableMessageDisplay();
 
     /** Returns true if the message view is scrolled to the bottom. */
-    bool atBottom() const;
+    void atBottom();
 
     bool isFixedFont() const;
     void setUseFixedFont(bool useFixedFont);
@@ -324,6 +325,7 @@ public:
     void runJavaScript(const QString &code);
 Q_SIGNALS:
     void moveMessageToTrash();
+    void pageIsScrolledToBottom(bool);
     void executeMailAction(MessageViewer::Viewer::MailAction type);
 
     /**
