@@ -25,6 +25,7 @@
 #include "loadexternalreferencesurlinterceptor/loadexternalreferencesurlinterceptor.h"
 #include "cidreferencesurlinterceptor/cidreferencesurlinterceptor.h"
 #include <WebEngineViewer/NetworkAccessManagerWebEngine>
+#include <WebEngineViewer/WebEngineManageScript>
 
 #include "scamdetection/scamdetectionwebengine.h"
 #include "scamdetection/scamcheckshorturl.h"
@@ -108,6 +109,15 @@ MailWebEngineView::~MailWebEngineView()
 }
 
 
+void MailWebEngineView::runJavaScriptInWordId(const QString &script)
+{
+#if QT_VERSION >= 0x050700
+    page()->runJavaScript(script, WebEngineViewer::WebEngineManageScript::scriptWordId());
+#else
+    page()->runJavaScript(script);
+#endif
+}
+
 void MailWebEngineView::initializeScripts()
 {
     initializeJQueryScript();
@@ -130,12 +140,12 @@ void MailWebEngineView::slotWebHitFinished(const WebEngineViewer::WebHitTestResu
 
 void MailWebEngineView::scrollUp(int pixels)
 {
-    page()->runJavaScript(WebEngineViewer::WebEngineScript::scrollUp(pixels));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::scrollUp(pixels));
 }
 
 void MailWebEngineView::scrollDown(int pixels)
 {
-    page()->runJavaScript(WebEngineViewer::WebEngineScript::scrollDown(pixels));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::scrollDown(pixels));
 }
 
 void MailWebEngineView::selectAll()
@@ -233,33 +243,56 @@ void MailWebEngineView::showAccessKeys()
     d->mWebViewAccessKey->showAccessKeys();
 }
 
-bool MailWebEngineView::isScrolledToBottom() const
+void MailWebEngineView::hideAccessKeys()
 {
-    qDebug() << "bool MailWebEngineView::isScrolledToBottom() const not implemented";
-    //Convert as async
-    //TODO '(window.innerHeight + window.scrollY) >= document.body.offsetHeight)'
-    return false;
+    d->mWebViewAccessKey->hideAccessKeys();
+}
+
+void MailWebEngineView::isScrolledToBottom()
+{
+#if QT_VERSION >= 0x050700
+    page()->runJavaScript(WebEngineViewer::WebEngineScript::isScrolledToBottom(),
+                          WebEngineViewer::WebEngineManageScript::scriptWordId(),
+                          invoke(this, &MailWebEngineView::handleIsScrolledToBottom));
+#else
+    page()->runJavaScript(WebEngineViewer::WebEngineScript::isScrolledToBottom(), invoke(this, &MailWebEngineView::handleIsScrolledToBottom));
+#endif
 }
 
 void MailWebEngineView::setElementByIdVisible(const QString &id, bool visible)
 {
-    page()->runJavaScript(WebEngineViewer::WebEngineScript::setElementByIdVisible(id, visible));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::setElementByIdVisible(id, visible));
 }
 
 void MailWebEngineView::removeAttachmentMarking(const QString &id)
 {
-    page()->runJavaScript(WebEngineViewer::WebEngineScript::removeStyleToElement(QLatin1String("*#") + id));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::removeStyleToElement(QLatin1String("*#") + id));
 }
 
 void MailWebEngineView::markAttachment(const QString &id, const QString &style)
 {
     //TODO verify "*#" + id
-    page()->runJavaScript(WebEngineViewer::WebEngineScript::setStyleToElement(QLatin1String("*#") + id, style));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::setStyleToElement(QLatin1String("*#") + id, style));
 }
 
 void MailWebEngineView::scrollToAnchor(const QString &anchor)
 {
+#if QT_VERSION >= 0x050700
+    page()->runJavaScript(WebEngineViewer::WebEngineScript::searchElementPosition(anchor),
+                          WebEngineViewer::WebEngineManageScript::scriptWordId(),
+                          invoke(this, &MailWebEngineView::handleScrollToAnchor));
+#else
     page()->runJavaScript(WebEngineViewer::WebEngineScript::searchElementPosition(anchor), invoke(this, &MailWebEngineView::handleScrollToAnchor));
+#endif
+}
+
+void MailWebEngineView::handleIsScrolledToBottom(const QVariant &result)
+{
+    bool scrolledToBottomResult = false;
+    if (result.isValid()) {
+        scrolledToBottomResult = result.toBool();
+    }
+    Q_EMIT pageIsScrolledToBottom(scrolledToBottomResult);
 }
 
 void MailWebEngineView::handleScrollToAnchor(const QVariant &result)
@@ -268,14 +301,14 @@ void MailWebEngineView::handleScrollToAnchor(const QVariant &result)
         const QList<QVariant> lst = result.toList();
         if (lst.count() == 2) {
             const QPoint pos(lst.at(0).toInt(), lst.at(1).toInt());
-            page()->runJavaScript(WebEngineViewer::WebEngineScript::scrollToPosition(pos));
+            runJavaScriptInWordId(WebEngineViewer::WebEngineScript::scrollToPosition(pos));
         }
     }
 }
 
 void MailWebEngineView::scrollPageDown(int percent)
 {
-    page()->runJavaScript(WebEngineViewer::WebEngineScript::scrollPercentage(percent));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::scrollPercentage(percent));
 }
 
 void MailWebEngineView::scrollPageUp(int percent)
@@ -288,7 +321,7 @@ void MailWebEngineView::executeCustomRenderingScripts()
     const QString scripts = MessageViewer::MailWebEngineScript::manageShowHideAttachments() +
                             MessageViewer::MailWebEngineScript::manageExpandAddresses(QStringLiteral("To")) +
                             MessageViewer::MailWebEngineScript::manageExpandAddresses(QStringLiteral("Cc"));
-    page()->runJavaScript(scripts);
+    runJavaScriptInWordId(scripts);
 }
 
 void MailWebEngineView::injectAttachments(const boost::function<QString()> &delayedHtml)
@@ -297,7 +330,7 @@ void MailWebEngineView::injectAttachments(const boost::function<QString()> &dela
     if (html.isEmpty()) {
         return;
     }
-    page()->runJavaScript(MessageViewer::MailWebEngineScript::injectAttachments(html, QStringLiteral("attachmentInjectionPoint")));
+    runJavaScriptInWordId(MessageViewer::MailWebEngineScript::injectAttachments(html, QStringLiteral("attachmentInjectionPoint")));
 }
 
 void MailWebEngineView::toggleFullAddressList(const QString &field, const boost::function<QString()> &delayedHtml)
@@ -308,7 +341,7 @@ void MailWebEngineView::toggleFullAddressList(const QString &field, const boost:
     }
 
     //qDebug() << "void MailWebEngineView::toggleFullAddressList(const QString &field, const boost::function<QString()> &delayedHtml, bool doShow)" << html << " fields " << field;
-    page()->runJavaScript(MessageViewer::MailWebEngineScript::replaceInnerHtml(field, html));
+    runJavaScriptInWordId(MessageViewer::MailWebEngineScript::replaceInnerHtml(field, html));
 }
 
 bool MailWebEngineView::hasVerticalScrollBar() const
@@ -328,7 +361,7 @@ bool MailWebEngineView::isAttachmentInjectionPoint(const QPoint &globalPos) cons
 
 void MailWebEngineView::scrollToRelativePosition(qreal pos)
 {
-    page()->runJavaScript(WebEngineViewer::WebEngineScript::scrollToRelativePosition(pos));
+    runJavaScriptInWordId(WebEngineViewer::WebEngineScript::scrollToRelativePosition(pos));
 }
 
 QUrl MailWebEngineView::linkOrImageUrlAt(const QPoint &global) const
@@ -374,3 +407,4 @@ void MailWebEngineView::dropEvent(QDropEvent *e)
     Q_UNUSED(e);
     qDebug() << " MailWebEngineView::dropEvent";
 }
+
