@@ -18,6 +18,7 @@
 */
 
 #include "testjquerysupportmailwebengine.h"
+#include <KActionCollection>
 #include <QHBoxLayout>
 #include <QApplication>
 #include <QWebEngineView>
@@ -37,7 +38,7 @@ TestJQuerySupportMailWebEngine::TestJQuerySupportMailWebEngine(QWidget *parent)
     : QWidget(parent)
 {
     QVBoxLayout *vboxLayout = new QVBoxLayout(this);
-    viewer = new MessageViewer::Viewer(0);
+    viewer = new MessageViewer::Viewer(0, 0 , new KActionCollection(this));
     vboxLayout->addWidget(viewer);
     viewer->setMessage(readAndParseMail(QStringLiteral("encapsulated-with-attachment.mbox")));
     viewer->setPluginName(QStringLiteral("enterprise"));
