@@ -18,6 +18,7 @@
 */
 #include "webengineaccesskeyanchorfromhtmltest.h"
 #include "../webengineaccesskeyutils.h"
+#include <WebEngineViewer/WebEngineManageScript>
 #include <QTest>
 #include <QHBoxLayout>
 #include <QWebEngineView>
@@ -74,7 +75,13 @@ void TestWebEngineAccessKey::handleSearchAccessKey(const QVariant &var)
 void TestWebEngineAccessKey::loadFinished(bool b)
 {
     Q_UNUSED(b);
+#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+    mEngineView->page()->runJavaScript(WebEngineViewer::WebEngineAccessKeyUtils::script(),
+                                       WebEngineViewer::WebEngineManageScript::scriptWordId(),
+                                       invoke(this, &TestWebEngineAccessKey::handleSearchAccessKey));
+#else
     mEngineView->page()->runJavaScript(WebEngineViewer::WebEngineAccessKeyUtils::script(), invoke(this, &TestWebEngineAccessKey::handleSearchAccessKey));
+#endif
 }
 
 Q_DECLARE_METATYPE(QVector<WebEngineViewer::WebEngineAccessKeyAnchor>)
