@@ -20,6 +20,7 @@
 #include "webengineaccesskey.h"
 #include "webengineaccesskeyanchor.h"
 #include "webengineaccesskeyutils.h"
+#include "webenginemanagescript.h"
 
 #include <KActionCollection>
 #include <QKeyEvent>
@@ -385,6 +386,12 @@ void WebEngineAccessKey::handleSearchAccessKey(const QVariant &res)
 void WebEngineAccessKey::showAccessKeys()
 {
     d->mAccessKeyActivated = WebEngineAccessKeyPrivate::Activated;
+#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
+    d->mWebEngine->page()->runJavaScript(WebEngineViewer::WebEngineAccessKeyUtils::script(),
+                                         WebEngineManageScript::scriptWordId(),
+                                         invoke(this, &WebEngineAccessKey::handleSearchAccessKey));
+#else
     d->mWebEngine->page()->runJavaScript(WebEngineViewer::WebEngineAccessKeyUtils::script(), invoke(this, &WebEngineAccessKey::handleSearchAccessKey));
+#endif
 }
 
